@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '2.0.1'
+__version__ = '2.1'
 __author__ = 'Zachary Voase <zacharyvoase@me.com>'
 
 
-import common
-from common import *
-
-import core
-from core import *
+from djctrl import common, core
+from djctrl.common import *
+from djctrl.core import *
 
 
 __all__ = vars().keys()
